"use strict";
const validator = require("validator");
const error_1 = require("../error");
exports.VALIDATION_NO_INT = 'VALIDATION_NO_INT';
exports.VALIDATION_NO_STRING = 'VALIDATION_NO_STRING';
exports.VALIDATION_NO_EMAIL = 'VALIDATION_NO_EMAIL';
exports.VALIDATION_INT_OUT_OF_BOUNDS = 'VALIDATION_INT_OUT_OF_BOUNDS';
exports.VALIDATION_STRING_OUT_OF_BOUNDS = 'VALIDATION_STRING_OUT_OF_BOUNDS';
exports.DEFAULT_CODE = 400;
class Validator {
    static isInt(value, min = Number.MIN_SAFE_INTEGER, max = Number.MAX_SAFE_INTEGER) {
        value = Validator.isString(value);
        if (!isNaN(value) && validator.isInt(value)) {
            value = parseInt(value);
            if (value < max && value > min) {
                return value;
            }
            throw new error_1.ResultError(exports.VALIDATION_INT_OUT_OF_BOUNDS, exports.DEFAULT_CODE, value);
        }
        throw new error_1.ResultError(exports.VALIDATION_NO_INT, exports.DEFAULT_CODE, value);
    }
    static escape(value) {
        return validator.escape(value || '');
    }
    static isString(value, min = 0, max = 256) {
        if (typeof value == 'string') {
            const processedValue = value.trim();
            if (processedValue.length > min && processedValue.length < max) {
                return Validator.escape(processedValue);
            }
            throw new error_1.ResultError(exports.VALIDATION_STRING_OUT_OF_BOUNDS, exports.DEFAULT_CODE, value);
        }
        throw new error_1.ResultError(exports.VALIDATION_NO_STRING, exports.DEFAULT_CODE, value);
    }
    static isEmail(value) {
        const email = Validator.isString(value).toLowerCase();
        if (validator.isEmail(email)) {
            return email;
        }
        else {
            throw new error_1.ResultError(exports.VALIDATION_NO_EMAIL, exports.DEFAULT_CODE, value);
        }
    }
}
exports.Validator = Validator;
